local bar = _G[...]
local modName = ...
local L

local function AddLayoutPanel(menu)
	local panel = menu:NewPanel(L.Layout)
	panel.opacitySlider = panel:NewOpacitySlider()
	panel.fadeSlider = panel:NewFadeSlider()
	panel.paddingSlider = panel:NewPaddingSlider()
	panel:NewSlider('Height', 250, 500, 1,
		function(self) --Getter
			self:SetValue(self:GetParent().owner.sets.height)
		end,
		function(self) --Setter
			self:GetParent().owner.sets.height = self:GetValue()
			self:GetParent().owner:Layout()
		end
	)
	panel:NewSlider('Width', 75, 165, 1,
		function(self) --Getter
			self:SetValue(self:GetParent().owner.sets.width)
		end,
		function(self) --Setter
			self:GetParent().owner.sets.width = self:GetValue()
			self:GetParent().owner:Layout()
		end
	)
	panel.scaleSlider = panel:NewScaleSlider()
	return panel
end

local function AddShowState(self)
	local p = self:NewPanel(L.ShowStates)
	p.height = 56
	local editBox = CreateFrame('EditBox', p:GetName() .. 'StateText', p, 'InputBoxTemplate')
	editBox:SetWidth(148) editBox:SetHeight(20)
	editBox:SetPoint('TOPLEFT', 12, -10)
	editBox:SetAutoFocus(false)
	editBox:SetScript('OnShow', function(self)
		self:SetText(self:GetParent().owner:GetShowStates() or '')
	end)
	editBox:SetScript('OnEnterPressed', function(self)
		local text = self:GetText()
		self:GetParent().owner:SetShowStates(text ~= '' and text or nil)
		self:ClearFocus()
	end)
	editBox:SetScript('OnEditFocusLost', function(self) self:HighlightText(0, 0) end)
	editBox:SetScript('OnEditFocusGained', function(self) self:HighlightText() end)
	local set = CreateFrame('Button', p:GetName() .. 'Set', p, 'UIPanelButtonTemplate')
	set:SetWidth(30) set:SetHeight(20)
	set:SetText(L.Set)
	set:SetScript('OnClick', function(self)
		local text = editBox:GetText()
		self:GetParent().owner:SetShowStates(text ~= '' and text or nil)
		editBox:SetText(self:GetParent().owner:GetShowStates() or '')
		editBox:ClearFocus()
	end)
	set:SetPoint('BOTTOMRIGHT', -8, 2)
	return p
end

local function AddAdvancedPanel(menu)
	local panel = menu:NewPanel(L.Advanced)
	panel:NewClickThroughCheckbox()
	panel:NewShowInOverrideUICheckbox()
	panel:NewShowInPetBattleUICheckbox()
	return panel
end

function bar:CreateMenu()
	local menu = Dominos:NewMenu(self.id)
	L = LibStub('AceLocale-3.0'):GetLocale('Dominos-Config')

	AddLayoutPanel(menu)

	if self.components then
		for i, b in pairs(self.components) do
			if b.CreateMenu and bar.Menu then
				b:CreateMenu(menu)
			end
		end
	end

	AddAdvancedPanel(menu)
	return menu
end


local menu, config
function bar:ShowMenu()
	if not bar.master:IsConfigAddonEnabled() then return end
	config = config or LoadAddOn('Dominos_Config')
	L = L or LibStub('AceLocale-3.0'):GetLocale('Dominos-Config')
	bar.menu = bar.menu or self:CreateMenu()

	local menu = bar.menu
	menu:Hide()
	menu:SetOwner(self)
	menu:ShowPanel(L.Layout)
	menu:Show()
end
